==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/TRIXIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { TRIXIndicatorDescription } from "./TRIXIndicatorDescription";
/**
 * @hidden
 */
export let TRIXIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class TRIXIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (TRIXIndicatorDescriptionMetadata.a == null) {
                TRIXIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TRIXIndicatorDescriptionMetadata.c(TRIXIndicatorDescriptionMetadata.a);
            }
            if (a.k(TRIXIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(TRIXIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            TRIXIndicatorDescriptionMetadata.b(a);
            a.ad("TRIXIndicator", () => new TRIXIndicatorDescription());
            a.ac("TRIXIndicator", TRIXIndicatorDescriptionMetadata.a);
        }
    }
    TRIXIndicatorDescriptionMetadata.$t = markType(TRIXIndicatorDescriptionMetadata, 'TRIXIndicatorDescriptionMetadata');
    TRIXIndicatorDescriptionMetadata.a = null;
    return TRIXIndicatorDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/TRIXIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { TRIXIndicatorDescription } from "./TRIXIndicatorDescription";
/**
 * @hidden
 */
export let TRIXIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class TRIXIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (TRIXIndicatorDescriptionMetadata.a == null) {
                TRIXIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TRIXIndicatorDescriptionMetadata.c(TRIXIndicatorDescriptionMetadata.a);
            }
            if (a.k(TRIXIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(TRIXIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            TRIXIndicatorDescriptionMetadata.b(a);
            a.ae("TRIXIndicator", () => new TRIXIndicatorDescription());
            a.ad("TRIXIndicator", TRIXIndicatorDescriptionMetadata.a);
        }
    }
    TRIXIndicatorDescriptionMetadata.$t = markType(TRIXIndicatorDescriptionMetadata, 'TRIXIndicatorDescriptionMetadata');
    TRIXIndicatorDescriptionMetadata.a = null;
    return TRIXIndicatorDescriptionMetadata;
})();
